Minifold
==============

.. _git: https://github.com/nokia/minifold.git 
.. _pybgl: https://github.com/nokia/pybgl.git 
.. _wiki: https://github.com/nokia/minifold/wiki
.. _LINCS: https://www.lincs.fr
.. _homepages: https://www.lincs.fr/people/?more=marc_olivier_buob
.. _trombinoscope: https://www.lincs.fr/people/
.. _graphs: https://www.lincs.fr/research/lincs-graph/
.. _graphviz: http://graphviz.org/
.. _Python3: http://python.org/

==================
Overview
==================

Minifold is a Python module able to interact with various data sources (e.g. CSV, LDAP, SQL, twitter, etc.) and to query/combine/aggregate them with database-like operators.

==================
Use cases
==================

This framework has been in various Nokia projects. It also used in the LINCS_ website to generate:

- trombinoscope_;
- homepages_;
- co-author graphs_ (thanks to pybgl_ and graphviz_).

===================
More about minifold
===================

.. _Overview: https://github.com/nokia/minifold/wiki/Overview
.. _Installation: https://github.com/nokia/minifold/wiki/Installation
.. _Tests: https://github.com/nokia/minifold/wiki/Tests
.. _Tutorial: https://github.com/nokia/minifold/wiki/Tutorial
.. _Design: https://github.com/nokia/minifold/wiki/Design
.. _Configuration: https://github.com/nokia/minifold/wiki/Configuration
.. _Framework: https://github.com/nokia/minifold/wiki/Framework
.. _Packaging: https://github.com/nokia/minifold/wiki/Packaging

For more information, feel free to visit the wiki_:

- Overview_
- Installation_
- Tests_
- Tutorial_ 
- Design_
- Configuration_
- Framework_
- Tests_
- Packaging_

=======
License
=======

This project is licensed under the BSD-3-Clause license - see the `LICENSE <https://github.com/nokia/minifold/blob/master/LICENSE>`_.
